{ pkgs }:

let
  zshCurried = import ../programs/zsh.nix { inherit pkgs; };
in

{ pkgs
, config,
... }:

let
  unstablepkgs = import <channels-nixos-unstable> { config = config.nixpkgs.config; };

in {
  imports = [
    ../profiles/common.nix
    ../programs/firefox.nix
    # ../programs/chromium.nix
    # FIXME: fix homeshick when no WAN connection is available
    # ../programs/homeshick.nix
    ../programs/libreoffice.nix
    ../programs/neovim.nix
    ../programs/pass.nix
    zshCurried
  ];

  nixpkgs.config = {
    pidgin = {
      openssl = true;
      gnutls = true;
    };

    packageOverrides = pkgs: with pkgs; {
    };
  };

  home.sessionVariables = {
  };


  home.packages =
    [] ++ (with pkgs; [
      # Nix package related tools
      patchelf
      nix-index
      nix-prefetch-scripts

      # Version Control Systems
      gitless

      # Process/System Administration
      htop
      gnome.gnome-tweaks
      xorg.xhost
      dmidecode
      evtest

      # Archive Managers
      sshfs-fuse
      xarchive
      p7zip
      zip
      unzip
      gzip
      lzop

      # Password Management
      gnome.gnome-keyring
      gnome.seahorse

      # Remote Control Tools
      remmina
      freerdp

      # Network Tools
      openvpn
      tcpdump
      iftop
      iperf
      bind
      socat

      # samba
      iptables
      nftables
      wireshark

      # Code Editors
      xclip
      xsel
      unstablepkgs.vscode

      # Image/Graphic/Design Tools
      gnome.eog
      gimp
      inkscape

      # Misc Development Tools
      qrcode
      jq
      cdrtools

      # Document Processing and Management
      zathura

      # File Synchronzation
      rsync

      # Filesystem Tools
      ntfs3g
      ddrescue
      ncdu
      unstablepkgs.woeusb
      unetbootin
      pcmanfm
      hdparm
      testdisk
      python38Packages.binwalk
      gptfdisk

      ## Python
      myPython

      busyboxStatic

      # Virtualization
      virtmanager
  ]);
}
